@@ -195,7 +195,7 @@ class BaseBarHelper:
         """
         begin_trading_date = YfTimeHelper.get_trading_day(begin_time)
         end_trading_day = YfTimeHelper.get_trading_day(end_time)
-        return BaseBarHelper.create_out_day_date_time_slice_by_date(begin_trading_date, end_trading_day, bar_type)
+        return BaseBarHelper.create_out_day_date_time_slice_by_date(begin_trading_date, end_trading_day, interval, bar_type)
 
     @staticmethod
     def create_in_day_date_time_slice_by_date_time(instrument_manager, instrument_id, begin_time, end_time, interval, bar_type, *instrument_ids):
